@@ -503,11 +503,12 @@ class _BaseDateTimeConverter(BaseConverter):
             if '%S' in format:
                 format = format.replace('%S', '')
 
-        # Strip trailing characters
-        while format[-1] in ('.', ':', ' '):
-            format = format[:-1]
-
-        return format
+        # Strip trailing characters. This will strip trailing characters
+        # anywhere, like:
+        #   'hh:mm: %p' => 'hh:mm %p'
+        #   ':hh:mm %p. ' => 'hh:mm %p'
+        return ' '.join([f.strip('.: ') for f in
+                         format.split(' ') if f.strip('.: ')])
 
     def get_mask(self):
         mask = self.get_format()
@@ -529,7 +530,8 @@ class _BaseDateTimeConverter(BaseConverter):
                 raise ValidationError(
                     _("You cannot enter a year before 1900"))
 
-        return value.strftime(format)
+        # strftime is appending an empty space on some cases, so strip them
+        return value.strftime(format).strip()
 
     def _convert_format(self, format):
         "Convert the format string to a 'human-readable' format"
@@ -638,7 +640,7 @@ class _EnumConverter(BaseConverter):
         if not isinstance(value, self.type):
             raise ValidationError(
                 "value must be an instance of %s, not %r" % (
-                self.type, value))
+                    self.type, value))
         return value.name
 
     def from_string(self, value):
