@@ -23,6 +23,7 @@
 
 """Distutils extensions and utilities"""
 
+import commands
 from distutils.command.clean import clean
 from distutils.command.install_data import install_data
 from distutils.command.install_lib import install_lib
@@ -119,7 +120,7 @@ class KiwiInstallLib(install_lib):
             return fp.read().split()[0]
 
     def generate_template(self):
-        if 'bdist_wininst' in sys.argv:
+        if 'bdist_wininst' in sys.argv or 'bdist_wheel' in sys.argv:
             prefix = 'sys.prefix'
         else:
             install = self.distribution.get_command_obj('install')
@@ -198,11 +199,19 @@ class KiwiInstallData(install_data):
 class KiwiClean(clean):
     def run(self):
         retval = clean.run(self)
-        info("Coping revision file")
         top_dir = os.path.dirname(os.path.abspath(sys.argv[0]))
-        src = os.path.join(top_dir, '.bzr', 'branch', 'last-revision')
         dest = os.path.join(top_dir, 'last-revision')
-        copyfile(src, dest)
+        git_src = os.path.join(top_dir, '.git', 'HEAD')
+        bzr_src = os.path.join(top_dir, '.bzr', 'branch', 'last-revision')
+        if os.path.exists(git_src):
+            status, output = commands.getstatusoutput(
+                'git rev-parse --short HEAD')
+            if status == 0:
+                info("Writing git revision file")
+                open(dest, 'w').write(output)
+        elif os.path.exists(bzr_src):
+            info("Copying bzr revision file")
+            copyfile(bzr_src, dest)
         return retval
 
 
@@ -210,11 +219,9 @@ def get_site_packages_dir(*dirs):
     """
     Gets the relative path of the site-packages directory
 
-    This is mainly useful for setup.py usage:
+    This is mainly useful for setup.py set usage:
 
-    >>> setup(...
-              data_files=[(get_site_packages_dir('foo'),
-                           files..)])
+        >>> data_files = [get_site_packages_dir('foo')]
 
     where files is a list of files to be installed in
     a directory called foo created in your site-packages directory
