@@ -30,6 +30,7 @@ import datetime
 import decimal
 import gettext
 import locale
+import logging
 import pickle
 
 import glib
@@ -42,7 +43,6 @@ from kiwi.accessor import kgetattr
 from kiwi.datatypes import converter, number, ValidationError
 from kiwi.currency import currency  # after datatypes
 from kiwi.enums import Alignment
-from kiwi.log import Logger
 from kiwi.python import enum, slicerange
 from kiwi.utils import gsignal, type_register
 from kiwi.ui.widgets.contextmenu import ContextMenu
@@ -50,7 +50,7 @@ from kiwi.ui.cellrenderer import EditableTextRenderer, EditableSpinRenderer
 
 _ = lambda m: gettext.dgettext('kiwi', m)
 
-log = Logger('objectlist')
+log = logging.getLogger('objectlist')
 
 
 def str2enum(value_name, enum_class):
@@ -1266,9 +1266,7 @@ class ObjectList(gtk.HBox):
                 self.clear()
                 return
 
-        model = self._model
         iters = self._iters
-
         old_instances = [row[COL_MODEL] for row in model]
 
         # Save selection
@@ -1280,6 +1278,13 @@ class ObjectList(gtk.HBox):
                 selected_instances = [model[path][COL_MODEL]
                                       for (path,) in paths]
 
+        # Remove sorting from the model to improve (significantly) performance
+        # http://www.pygtk.org/pygtk2tutorial/sec-TreeModelInterface.html#sec-LargeDataStores
+        if self._sortable:
+            for index, column in enumerate(self._columns):
+                model.set_sort_func(index, lambda *args: -1,
+                                    (column, column.attribute))
+
         iters = self._iters
         prev = None
         # Do not always just clear the list, check if we have the same
@@ -1313,6 +1318,12 @@ class ObjectList(gtk.HBox):
             for instance in iter(instances):
                 self._iters[instance] = self._model_append(instance)
 
+        # Re-set the model for the treeview and the ordering
+        if self._sortable:
+            for index, column in enumerate(self._columns):
+                model.set_sort_func(index, self._model_sort_func,
+                                    (column, column.attribute))
+
         # Restore selection
         for instance in selected_instances:
             objid = instance
@@ -2124,8 +2135,10 @@ class ObjectTree(ObjectList):
         self.get_treeview().connect('row-expanded', self._on_treeview__row_expanded)
 
     def __iter__(self):
-        # FIXME: This should be sorted in the order the objects are displayed
-        return self._iters.iterkeys()
+        for obj in self._model:
+            yield obj[COL_MODEL]
+            for child in obj.iterchildren():
+                yield child[COL_MODEL]
 
     def _append_internal(self, parent, instance, select, prepend):
         iters = self._iters
