@@ -28,17 +28,17 @@
 to keep the state of a model object synchronized with a View.
 """
 
+import logging
+
 import gobject
 import gtk
 
 from kiwi import ValueUnset
 from kiwi.accessor import kgetattr, ksetattr, clear_attr_cache
 from kiwi.datatypes import converter
-from kiwi.decorators import deprecated
 from kiwi.interfaces import IProxyWidget, IValidatableProxyWidget
-from kiwi.log import Logger
 
-log = Logger('proxy')
+log = logging.getLogger('proxy')
 
 
 class ProxyError(Exception):
@@ -100,8 +100,8 @@ class Proxy:
     # Private API
 
     def _update_attribute(self, widget, attribute, value):
-        log('%s.%s = %r' %
-            (self._model.__class__.__name__, attribute, value))
+        log.debug('%s.%s = %r' %
+                  (self._model.__class__.__name__, attribute, value))
 
         # only update the model if the data is correct
         if value is ValueUnset:
@@ -424,9 +424,3 @@ class Proxy:
             for data_name in ('notify-visible-id',
                               'notify-sensitive-id'):
                 widget.disconnect(widget.get_data(data_name))
-
-    # Backwards compatibility
-
-    def new_model(self, model, relax_type=False):
-        self.set_model(model)
-    new_model = deprecated('set_model', log)(new_model)
