@@ -30,8 +30,7 @@ import gobject
 import gtk
 
 from kiwi import ValueUnset
-from kiwi.python import deprecationwarn
-from kiwi.utils import gsignal, type_register
+from kiwi.utils import gsignal
 from kiwi.ui.proxywidget import ProxyWidgetMixin
 
 
@@ -95,12 +94,4 @@ class ProxyRadioButton(gtk.RadioButton, ProxyWidgetMixin):
             if rb.get_property('data-value') == data:
                 rb.set_active(True)
 
-
-class RadioButton(ProxyRadioButton):
-    def __init__(self):
-        deprecationwarn(
-            'RadioButton is deprecated, use ProxyRadioButton instead',
-            stacklevel=3)
-        ProxyRadioButton.__init__(self)
-
-type_register(RadioButton)
+gobject.type_register(ProxyRadioButton)
